This is an automated email from the ASF dual-hosted git repository.

rubys pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/whimsy.git


The following commit(s) were added to refs/heads/master by this push:
     new 9299314  only show reports posted since the last board meeting
9299314 is described below

commit 9299314bce670c6c7e244a595fe39686a5c439da
Author: Sam Ruby <[email protected]>
AuthorDate: Mon Oct 2 13:36:59 2017 -0400

    only show reports posted since the last board meeting
---
 www/board/agenda/views/actions/posted-reports.json.rb | 9 +++++++--
 1 file changed, 7 insertions(+), 2 deletions(-)

diff --git a/www/board/agenda/views/actions/posted-reports.json.rb 
b/www/board/agenda/views/actions/posted-reports.json.rb
index db0a7e3..4b28024 100755
--- a/www/board/agenda/views/actions/posted-reports.json.rb
+++ b/www/board/agenda/views/actions/posted-reports.json.rb
@@ -10,10 +10,15 @@ require 'whimsy/asf/agenda'
 THREAD = "https://lists.apache.org/thread.html/";
 
 # only look at this month's and last month's mailboxes, and within those
 # only look at emails that were received in the last month.
 current = Date.today.strftime('%Y%m')
 previous = (Date.parse(current + '01')-1).strftime('%Y%m')
-cuttoff = (Date.today << 1).to_time
+last_meeting = Dir["#{FOUNDATION_BOARD}/board_agenda_*.txt"].sort[-2]
+if last_meeting
+  cutoff = (Date.parse(last_meeting[/\d[_\d]+/].gsub('_', '-'))+1).to_time
+else
+  cuttoff = (Date.today << 1).to_time
+end
 
 # get a list of current board messages
 archive = Dir["/srv/mail/board/#{previous}/*", "/srv/mail/board/#{current}/*"]
@@ -10,10 +10,15 @@ require 'whimsy/asf/agenda'
 
 # only look at this month's and last month's mailboxes, and within those
-# only look at emails that were received in the last month.
+# only look at emails that were received since the previous board meeting.
 current = Date.today.strftime('%Y%m')
 previous = (Date.parse(current + '01')-1).strftime('%Y%m')

-- 
To stop receiving notification emails like this one, please contact
['"[email protected]" <[email protected]>'].

Reply via email to